@@ -18,26 +18,25 @@ __email__ = "poul@mpie.de"
 __status__ = "production"
 __date__ = "23 Jun, 2020"
 
+
 def register(parser):
     parser.add_argument(
-            "project", default = ".", nargs = "?",
-            help = "path to pyiron project"
+        "project", default=".", nargs="?", help="path to pyiron project"
     )
     parser.add_argument(
-            "-j", "--jobs-only", action = "store_true",
-            help = "only remove jobs inside project"
+        "-j", "--jobs-only", action="store_true", help="only remove jobs inside project"
     )
     parser.add_argument(
-            "-r", "--recursive", action = "store_true",
-            help = "recurse into subprojects"
+        "-r", "--recursive", action="store_true", help="recurse into subprojects"
     )
 
+
 def main(args):
 
     pr = Project(args.project)
     if args.jobs_only:
-        pr.remove_jobs_silently(recursive = args.recursive)
+        pr.remove_jobs(recursive=args.recursive, silently=True)
     else:
-        pr.remove(enable = True)
+        pr.remove(enable=True)
         if not os.listdir(args.project):
             os.rmdir(args.project)
