@@ -103,7 +103,7 @@ class IsDatabase(ABC):
         for key in kwargs.keys():
             if key not in list(df.columns):
                 raise ValueError(
-                    "Column name {} does not exist in the project database!"
+                    f"Column name {key} does not exist in the project database!"
                 )
         for key, val in kwargs.items():
             if val is None:
@@ -347,28 +347,30 @@ class AutorestoredConnection:
     def execute(self, *args, **kwargs):
         while True:
             try:
-                if self._conn is None or self._conn.closed:
-                    self._conn = self.engine.connect()
-                    if self._timeout > 0:
-                        # only log reconnections when we keep the connection alive between requests otherwise we'll spam
-                        # the log
-                        if self._conn is None:
-                            self._logger.info(
-                                "Reconnecting to DB; connection not existing."
-                            )
-                        else:
-                            self._logger.info("Reconnecting to DB; connection closed.")
-                        if self._watchdog is not None:
-                            # in case connection is dead, but watchdog is still up, something else killed the connection,
-                            # make the watchdog quit, then making a new one
-                            self._watchdog.kill()
-                        self._watchdog = ConnectionWatchDog(
-                            self._conn, self._lock, timeout=self._timeout
-                        )
-                        self._watchdog.start()
-                if self._timeout > 0:
-                    self._watchdog.kick()
                 with self._lock:
+                    if self._conn is None or self._conn.closed:
+                        self._conn = self.engine.connect()
+                        if self._timeout > 0:
+                            # only log reconnections when we keep the connection alive between requests otherwise we'll spam
+                            # the log
+                            if self._conn is None:
+                                self._logger.info(
+                                    "Reconnecting to DB; connection not existing."
+                                )
+                            else:
+                                self._logger.info(
+                                    "Reconnecting to DB; connection closed."
+                                )
+                            if self._watchdog is not None:
+                                # in case connection is dead, but watchdog is still up, something else killed the connection,
+                                # make the watchdog quit, then making a new one
+                                self._watchdog.kill()
+                            self._watchdog = ConnectionWatchDog(
+                                self._conn, self._lock, timeout=self._timeout
+                            )
+                            self._watchdog.start()
+                    if self._timeout > 0:
+                        self._watchdog.kick()
                     result = self._conn.execute(*args, **kwargs)
                     break
             except OperationalError as e:
