@@ -59,34 +59,24 @@ class InteractiveWrapper(GenericMaster):
         self.append(ref_job)
 
     def set_input_to_read_only(self):
-        """
-        This function enforces read-only mode for the input classes, but it has to be implement in the individual
-        classes.
-        """
         self.input.read_only = True
 
+    set_input_to_read_only.__doc__ = GenericMaster.set_input_to_read_only.__doc__
+
     def validate_ready_to_run(self):
-        """
-        Validate that the calculation is ready to be executed. By default no generic checks are performed, but one could
-        check that the input information is complete or validate the consistency of the input at this point.
-        """
         self.ref_job.validate_ready_to_run()
 
+    validate_ready_to_run.__doc__ = GenericMaster.validate_ready_to_run.__doc__
+
     def check_setup(self):
-        """
-        Checks whether certain parameters (such as plane wave cutoff radius in DFT) are changed from the pyiron standard
-        values to allow for a physically meaningful results. This function is called manually or only when the job is
-        submitted to the queueing system.
-        """
         try:
             self.ref_job.check_setup()
         except AttributeError:
             pass
 
-    def ref_job_initialize(self):
-        """
+    check_setup.__doc__ = GenericMaster.check_setup.__doc__
 
-        """
+    def ref_job_initialize(self):
         if len(self._job_name_lst) > 0:
             self._ref_job = self.pop(-1)
             if self._job_id is not None and self._ref_job._master_id is None:
@@ -94,19 +84,14 @@ class InteractiveWrapper(GenericMaster):
                 self._ref_job.server.cores = self.server.cores
 
     def to_hdf(self, hdf=None, group_name=None):
-        """
-        Store the InteractiveWrapper in an HDF5 file
-
-        Args:
-            hdf (ProjectHDFio): HDF5 group object - optional
-            group_name (str): HDF5 subgroup name - optional
-        """
         if self._ref_job is not None and self._ref_job.job_id is None:
             self.append(self._ref_job)
         super(InteractiveWrapper, self).to_hdf(hdf=hdf, group_name=group_name)
         with self.project_hdf5.open("input") as hdf5_input:
             self.input.to_hdf(hdf5_input)
 
+    to_hdf.__doc__ = GenericMaster.to_hdf.__doc__
+
     def from_hdf(self, hdf=None, group_name=None):
         """
         Restore the InteractiveWrapper from an HDF5 file
@@ -119,10 +104,9 @@ class InteractiveWrapper(GenericMaster):
         with self.project_hdf5.open("input") as hdf5_input:
             self.input.from_hdf(hdf5_input)
 
-    def collect_output(self):
-        pass
+    from_hdf.__doc__ = GenericMaster.from_hdf.__doc__
 
-    def collect_logfiles(self):
+    def collect_output(self):
         pass
 
     def _db_entry_update_run_time(self):
@@ -153,15 +137,6 @@ class InteractiveWrapper(GenericMaster):
         self.send_to_database()
         self.update_master()
 
-    def _init_child_job(self, parent):
-        """
-        Set the job that created us as reference job.
-
-        Args:
-            master (:class:`.GenericJob`): job instance that this job was created from
-        """
-        self.ref_job = parent
-
     def __getitem__(self, item):
         """
         Get/ read data from the GenericMaster
